/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2010, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.java2d;

import java.awt.event.InputEvent;
import java.awt.event.MouseEvent;

/** The event that signals that some scene node is being dragged. */

public class TransformedMouseEvent extends java.util.EventObject {
    private static final long serialVersionUID = 1984L;

	int index;
	MouseEvent mouseEvent;
	double posX;
	double posY;
	InputEvent modifiers;
	
	static int AREA = -1;
	static int OUTLINE = -2;
	
	public TransformedMouseEvent (
		Object source,
		MouseEvent e,
		int indexOfHitPart,
		double x,
		double y
	) {
		super(source);
		mouseEvent = e;
		index = indexOfHitPart;
		posX = x;
		posY = y;
	}
	
	/** Tells which part of the component is being dragged. A non-negative integer j
	 * indicates that the point of the point set with index j is dragged.
	 * The negative integers AREA or OUTLINE indicate that the shape or its
	 * outline are dragged. */
	
	public int getIndexOfHitPart() {
		return index;
	}
	
	/** A general modifier flag, could correspond to the shift key of a
	 * keyboard being pressed during this drag operation. */
	
	public MouseEvent getMouseEvent() {
		return mouseEvent;
	}
	
	/** The x-coordinate (in user space) of this event's position. */
	
	public double getX() {
		return posX;
	}
	
	/** The y-coordinate (in user space) of this event's position. */
	
	public double getY() {
		return posY;
	}
	
	/** This is not the same as mouseEvent.getButton() but a version that
	 * works better on various platforms. */
	
	public int getButton() {
		int button = mouseEvent.getButton();
		if (button == 0)	{		// Linux!
			int mods = mouseEvent.getModifiersEx();
			if ((mods & InputEvent.BUTTON1_DOWN_MASK) != 0)		button = 1;
			else if ((mods & InputEvent.BUTTON2_DOWN_MASK) != 0)  button = 2;
			else button = 3;
		} else {					// Mac OS X Laptop (no 3-mouse button)!!
			int mods = mouseEvent.getModifiers();
			if (mouseEvent.isAltDown() && ((mods & InputEvent.BUTTON2_MASK) != 0) ) button = 2;
			else if (button == 1 &&  ((mods & InputEvent.BUTTON3_MASK) != 0) ) button = 3;
		}
		return button;
	}
}

