/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2010, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.java2dx;

import java.util.Collection;
import java.util.LinkedList;

public class Point2DList extends LinkedList<Point2DDouble> {

	private static final long serialVersionUID = 3102836280968164701L;
	final transient int hashCode = new Object().hashCode();
	
	public Point2DList() {}
	
	/**
	 * Makes copies of all the points.
	 * @param points
	 */
	public Point2DList(Collection<Point2DDouble> p) {
		assign(p);
	}
	
	public Point2DList(double[][] d) {
		assign(d);
	}
	
	public void assign(double[][] d) {
		clear();
		int n = d.length;
		for (int j=0; j<n; j++) {
			add(new Point2DDouble(d[j][0],d[j][1]));
		}
	}
	
	public void assign(Collection<Point2DDouble> p) {
		clear();
		for (Point2DDouble q : p) {
			add(new Point2DDouble(q));
		}
	}
	
	public double[][] toDoubleArray() {
		int n = size();
		double [][] d = new double[n][2];
		for (int j=0; j<n; j++) {
			Point2DDouble p = get(j);
			d[j][0] = p.x;
			d[j][1] = p.y;
		}
		return d;
	}
	
	/** Instances of this class return the same hashCode throughout
	 * their lifetime. Hence they are usable as keys in HashMaps.
	 */
	
	public int hashCode() {
		return hashCode;
	}
	
	/**
	 * Instance of this class are equal only if they are identical.
	 */
	public boolean equals(Object o) {
		return o==this;
	}
}
