/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2010, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.java2dx.beans;

import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.beans.SimpleBeanInfo;

import de.jtem.beans.SymmetricShapeEditor;
import de.jtem.java2d.SceneComponent;

public class SceneComponentBeanInfo extends SimpleBeanInfo {
	public PropertyDescriptor[] getPropertyDescriptors() {
		Class beanClass = SceneComponent.class;
		PropertyDescriptor[] rv = null;
		try {  
			PropertyDescriptor areaDragEnabled =
				new PropertyDescriptor("areaDragEnabled", beanClass);
			PropertyDescriptor outlineDragEnabled =
				new PropertyDescriptor("outlineDragEnabled", beanClass);
			PropertyDescriptor pointDragEnabled =
				new PropertyDescriptor("pointDragEnabled", beanClass);
			PropertyDescriptor annotationDragEnabled =
				new PropertyDescriptor("annotationDragEnabled", beanClass);
			PropertyDescriptor iconDragEnabled =
				new PropertyDescriptor("iconDragEnabled", beanClass);
			PropertyDescriptor mouseOverEnabled =
				new PropertyDescriptor("mouseOverEnabled", beanClass);
			PropertyDescriptor name =
				new PropertyDescriptor("name", beanClass);
			PropertyDescriptor highlighted =
				new PropertyDescriptor("highlighted", beanClass);
			PropertyDescriptor filled =
				new PropertyDescriptor("filled", beanClass);
			PropertyDescriptor paint =
				new PropertyDescriptor("paint", beanClass);
			PropertyDescriptor highlightPaint =
				new PropertyDescriptor("highlightPaint", beanClass);
			PropertyDescriptor outlined =
				new PropertyDescriptor("outlined", beanClass);
			PropertyDescriptor stroke =
				new PropertyDescriptor("stroke", beanClass);
			PropertyDescriptor pointFilled =
				new PropertyDescriptor("pointFilled", beanClass);
			PropertyDescriptor pointOutlined =
				new PropertyDescriptor("pointOutlined", beanClass);
			PropertyDescriptor pointShape =
				new PropertyDescriptor("pointShape", beanClass);
			pointShape.setPropertyEditorClass(
					SymmetricShapeEditor.WithNullOption.class
			);
			PropertyDescriptor pointStroke =
				new PropertyDescriptor("pointStroke", beanClass);
			PropertyDescriptor pointPaint =
				new PropertyDescriptor("pointPaint", beanClass);
			PropertyDescriptor highlightPointPaint =
				new PropertyDescriptor("highlightPointPaint", beanClass);
			PropertyDescriptor outlinePaint =
				new PropertyDescriptor("outlinePaint", beanClass);
			PropertyDescriptor highlightOutlinePaint =
				new PropertyDescriptor("highlightOutlinePaint", beanClass);
			PropertyDescriptor annotated =
				new PropertyDescriptor("annotated", beanClass);
			PropertyDescriptor annotationPaint =
				new PropertyDescriptor("annotationPaint", beanClass);
			PropertyDescriptor highlightAnnotationPaint =
				new PropertyDescriptor("highlightAnnotationPaint", beanClass);
			PropertyDescriptor font =
				new PropertyDescriptor("font", beanClass);
			PropertyDescriptor annotationMargin =
				new PropertyDescriptor("annotationMargin", beanClass);

			rv = new PropertyDescriptor[] {
					areaDragEnabled,
					outlineDragEnabled,
					pointDragEnabled,
					annotationDragEnabled,
					iconDragEnabled,
					mouseOverEnabled,
					name,
					highlighted,
					filled,
					paint,
					highlightPaint,
					outlined,
					stroke,
					pointFilled,
					pointOutlined,
					pointShape,
					pointStroke,
					pointPaint,
					highlightPointPaint,
					outlinePaint,
					highlightOutlinePaint,
					annotated,
					annotationPaint,
					highlightAnnotationPaint,
					font,
					annotationMargin
			};
			
		} catch (IntrospectionException e) {
			e.printStackTrace();
		}
		return rv;
	}
}
