/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2010, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.java2dx.numerical;


import java.awt.Paint;
import java.awt.Stroke;
import java.awt.geom.GeneralPath;
import java.awt.geom.Rectangle2D;

import de.jtem.java2d.SceneComponent;
import de.jtem.java2d.ViewportChangeEvent;
import de.jtem.java2d.ViewportChangeListener;


public class FunctionPlot implements ViewportChangeListener {
	private RealFunctionOnInterval function;
	private String name;
	private SceneComponent view = new SceneComponent();
	private int sampling = 300;
	private Rectangle2D.Double rectangle;
	
	public FunctionPlot(RealFunctionOnInterval f, Rectangle2D.Double r) {
		rectangle = r;
		function = f;
		view.setFilled(Boolean.FALSE);
		updateViewFromModel();
	}
	
	protected void updateViewFromModel() {
		if (function != null) {
			double minX = Math.max(
					rectangle.x,
					function.getLowerBoundOfInterval()
			);
			double maxX = Math.min(
					rectangle.x+rectangle.width,
					function.getUpperBoundOfInterval()
			);
			double dx = (maxX-minX)/sampling;
			
			GeneralPath path = new GeneralPath();
			double x = minX;
			double y = function.value(x);
			path.moveTo((float)x, (float)y);
			for (int j = 1; j<sampling+1; j++) {
				x = minX + j*dx;
				y = function.value(x);
				path.lineTo((float)x, (float)y);
			}
			
			view.setShape(path);
		}
	}
	
	public void modelChanged() {
		updateViewFromModel();
		view.fireAppearanceChange();
	}
	
	public Object getModel() {
		return function;
	}
	
	public Paint getPaint() {
		return view.getOutlinePaint();
	}

	public void setPaint(Paint paint) {
		view.setOutlinePaint(paint);
	}

	public Stroke getStroke() {
		return view.getStroke();
	}
	
	public void setStroke(Stroke stroke) {
		view.setStroke(stroke);
	}

	public SceneComponent getViewScene() {
		return view;
	}

	public RealFunctionOnInterval getFunction() {
		return function;
	}

	public void setFunction(RealFunctionOnInterval function) {
		this.function = function;
	}

	public Rectangle2D.Double getRectangle() {
		return rectangle;
	}

	public void setRectangle(Rectangle2D.Double rectangle) {
		this.rectangle = rectangle;
	}

	public void viewportChange(ViewportChangeEvent e) {
		rectangle = e.getViewport();
		updateViewFromModel();
		view.fireAppearanceChange();
	}

	public int getSampling() {
		return sampling;
	}

	public void setSampling(int sampling) {
		this.sampling = sampling;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}
}
