/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2010, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.java2dx.plugin;

import java.awt.Dimension;
import java.awt.GridLayout;

import javax.swing.Icon;

import de.jtem.java2dx.beans.Viewer2DWithInspector;
import de.jtem.java2dx.plugin.icon.ImageHook;
import de.jtem.jrworkspace.plugin.Controller;
import de.jtem.jrworkspace.plugin.PluginInfo;
import de.jtem.jrworkspace.plugin.sidecontainer.SideContainerPerspective;
import de.jtem.jrworkspace.plugin.simplecontroller.SimpleController;

public class Java2DView extends SideContainerPerspective {

	private Viewer2DWithInspector viewer;
	
	public Java2DView() {
		super();
		viewer = new Viewer2DWithInspector();
	}
	
	@Override
	public void install(Controller c) throws Exception {
		getContentPanel().setLayout(new GridLayout());
		getContentPanel().add(viewer);
		getContentPanel().setPreferredSize(new Dimension(800,600));
		getContentPanel().setMinimumSize(new Dimension(300, 200));
	}
	
	public Viewer2DWithInspector getViewer2D() {
		return viewer;
	}
	
	@Override
	public PluginInfo getPluginInfo() {
		PluginInfo info = new PluginInfo();
		info.name = "View";
		info.vendorName = "Ulrich Pinkall"; 
		info.icon = ImageHook.getIcon("hausgruen.png");
		info.isDynamic = false;
		return info;
	}

	public Icon getIcon() {
		return getPluginInfo().icon;
	}

	public String getTitle() {
		return "java2d";
	}

	public void setVisible(boolean visible) {
	}

	public static void main(String[] args) {
		SimpleController c = new SimpleController();
		c.registerPlugin(new Java2DView());
		c.registerPlugin(new Java2DViewMenuBar());
		c.registerPlugin(new Viewer2DInspector());
		c.registerPlugin(new GridInspector());
		c.startup();
	}
}
